@@ -185,55 +185,50 @@ impl Build {
             let rustc_meta = rustc_version::version_meta()?;
             let host_target = &rustc_meta.host;
             for (parsed_target, raw_target) in rust_targets.iter().zip(&self.cargo.target) {
-                // we only setup zig as linker when target isn't exactly the same as host target
-                if host_target != raw_target {
-                    let env_target = parsed_target.replace('-', "_");
-                    let (zig_cc, zig_cxx) = prepare_zig_linker(raw_target)?;
-                    if is_mingw_shell() {
-                        let zig_cc = zig_cc.to_slash_lossy();
-                        build.env(format!("CC_{}", env_target), &zig_cc);
-                        build.env(format!("CXX_{}", env_target), &zig_cxx.to_slash_lossy());
-                        build.env(
-                            format!("CARGO_TARGET_{}_LINKER", env_target.to_uppercase()),
-                            &zig_cc,
-                        );
-                    } else {
-                        build.env(format!("CC_{}", env_target), &zig_cc);
-                        build.env(format!("CXX_{}", env_target), &zig_cxx);
-                        build.env(
-                            format!("CARGO_TARGET_{}_LINKER", env_target.to_uppercase()),
-                            &zig_cc,
-                        );
-                    }
+                let env_target = parsed_target.replace('-', "_");
+                let (zig_cc, zig_cxx) = prepare_zig_linker(raw_target)?;
+                if is_mingw_shell() {
+                    let zig_cc = zig_cc.to_slash_lossy();
+                    build.env(format!("CC_{}", env_target), &zig_cc);
+                    build.env(format!("CXX_{}", env_target), &zig_cxx.to_slash_lossy());
+                    build.env(
+                        format!("CARGO_TARGET_{}_LINKER", env_target.to_uppercase()),
+                        &zig_cc,
+                    );
+                } else {
+                    build.env(format!("CC_{}", env_target), &zig_cc);
+                    build.env(format!("CXX_{}", env_target), &zig_cxx);
+                    build.env(
+                        format!("CARGO_TARGET_{}_LINKER", env_target.to_uppercase()),
+                        &zig_cc,
+                    );
+                }
 
-                    self.setup_os_deps()?;
+                self.setup_os_deps()?;
 
-                    if raw_target.contains("windows-gnu") {
-                        build.env("WINAPI_NO_BUNDLED_LIBRARIES", "1");
-                    }
+                if raw_target.contains("windows-gnu") {
+                    build.env("WINAPI_NO_BUNDLED_LIBRARIES", "1");
+                }
 
-                    if raw_target.contains("apple-darwin") {
-                        if let Some(sdkroot) = env::var_os("SDKROOT") {
-                            if !sdkroot.is_empty()
-                                && env::var_os("PKG_CONFIG_SYSROOT_DIR").is_none()
-                            {
-                                // Set PKG_CONFIG_SYSROOT_DIR for pkg-config crate
-                                build.env("PKG_CONFIG_SYSROOT_DIR", sdkroot);
-                            }
+                if raw_target.contains("apple-darwin") {
+                    if let Some(sdkroot) = env::var_os("SDKROOT") {
+                        if !sdkroot.is_empty() && env::var_os("PKG_CONFIG_SYSROOT_DIR").is_none() {
+                            // Set PKG_CONFIG_SYSROOT_DIR for pkg-config crate
+                            build.env("PKG_CONFIG_SYSROOT_DIR", sdkroot);
                         }
                     }
+                }
 
-                    // Enable unstable `target-applies-to-host` option automatically
-                    // when target is the same as host but may have specified glibc version
-                    if host_target == parsed_target {
-                        if !matches!(rustc_meta.channel, rustc_version::Channel::Nightly) {
-                            // Hack to use the unstable feature on stable Rust
-                            // https://github.com/rust-lang/cargo/pull/9753#issuecomment-1022919343
-                            build.env("__CARGO_TEST_CHANNEL_OVERRIDE_DO_NOT_USE_THIS", "nightly");
-                        }
-                        build.env("CARGO_UNSTABLE_TARGET_APPLIES_TO_HOST", "true");
-                        build.env("CARGO_TARGET_APPLIES_TO_HOST", "false");
+                // Enable unstable `target-applies-to-host` option automatically
+                // when target is the same as host but may have specified glibc version
+                if host_target == parsed_target {
+                    if !matches!(rustc_meta.channel, rustc_version::Channel::Nightly) {
+                        // Hack to use the unstable feature on stable Rust
+                        // https://github.com/rust-lang/cargo/pull/9753#issuecomment-1022919343
+                        build.env("__CARGO_TEST_CHANNEL_OVERRIDE_DO_NOT_USE_THIS", "nightly");
                     }
+                    build.env("CARGO_UNSTABLE_TARGET_APPLIES_TO_HOST", "true");
+                    build.env("CARGO_TARGET_APPLIES_TO_HOST", "false");
                 }
             }
         }
